/*
 * Omage DP97 precision digital thermometer device support
 */

#include <epicsStdio.h>
#include <devCommonGpib.h>

/******************************************************************************
 *
 * The following define statements are used to declare the names to be used
 * for the dset tables.   
 *
 * A DSET_AI entry must be declared here and referenced in an application
 * database description file even if the device provides no AI records.
 *
 ******************************************************************************/
#define DSET_AI     devAiDP97
#define DSET_MBBO   devMbboDP97

#include <devGpib.h> /* must be included after DSET defines */

#define TIMEOUT     3.0    /* I/O must complete within this time */
#define TIMEWINDOW  3.0    /* Wait this long after device timeout */

static char *unitSelect[] = {"OH\r", "C\r", "K\r", "F\r", 0};
static char *inputSelect[] = {"A\r", "B\r", "A-B\r", 0};

/******************************************************************************
 * Array of structures that define all GPIB messages
 * supported for this type of instrument.
 ******************************************************************************/

static struct gpibCmd gpibCmds[] = {
    /* Param 0 */
    {&DSET_AI,GPIBREAD,IB_Q_LOW,"ME\r","0 ,%lf",0,32,0,0,0,NULL,NULL,"\n"},
    /* Param 1 */
    {&DSET_MBBO,GPIBEFASTO,IB_Q_LOW,"UN ",NULL,32,32,0,0,0,unitSelect,NULL,"\n"},
    /* Param 2 */
    {&DSET_MBBO,GPIBEFASTO,IB_Q_LOW,"IN ",NULL,32,32,0,0,0,inputSelect,NULL,"\n"},
};

/* The following is the number of elements in the command array above.  */
#define NUMPARAMS sizeof(gpibCmds)/sizeof(struct gpibCmd)

/******************************************************************************
 * Initialize device support parameters
 *
 *****************************************************************************/
static long init_ai(int parm)
{
    if(parm==0) {
        devSupParms.name = "devDP97";
        devSupParms.gpibCmds = gpibCmds;
        devSupParms.numparams = NUMPARAMS;
        devSupParms.timeout = TIMEOUT;
        devSupParms.timeWindow = TIMEWINDOW;
        devSupParms.respond2Writes = 0;
    }
    return(0);
}
